//
//  GameKitExampleViewController.m
//  GameKitExample
//
//  Created by Brad Larson on 3/15/2010.
//

#import "GameKitExampleViewController.h"
#import "MATCGlossyButton.h"

@implementation GameKitExampleViewController

#pragma mark -
#pragma mark Initialization and teardown

- (void)viewDidLoad 
{
    [super viewDidLoad];
	
	colorButton.buttonColor = [UIColor greenColor];
	colorButton.cornerRadius = 10.0f;

	NSString *uid = [[UIDevice currentDevice] uniqueIdentifier];
	gameUniqueID = [uid hash];
		
	GKPeerPickerController *picker;
	
	picker = [[GKPeerPickerController alloc] init];
	picker.delegate = self;
	
	
	[picker show];
}

- (void)dealloc 
{
	[self invalidateSession:self.connectionSession];
	self.connectionSession = nil;
	self.connectionPeerId = nil;
	
    [super dealloc];
}

#pragma mark -
#pragma mark Button methods

- (IBAction)buttonDown:(id)sender;
{
	colorButton.buttonColor = [UIColor redColor];

	char buttonState = 1;
	NSData *packet = [NSData dataWithBytes:&buttonState length:sizeof(char)];
	[self.connectionSession sendData:packet toPeers:[NSArray arrayWithObject:connectionPeerId] withDataMode:GKSendDataReliable error:nil];
}

- (IBAction)buttonUp:(id)sender;
{
	colorButton.buttonColor = [UIColor greenColor];

	char buttonState = 0;
	NSData *packet = [NSData dataWithBytes:&buttonState length:sizeof(char)];
	[self.connectionSession sendData:packet toPeers:[NSArray arrayWithObject:connectionPeerId] withDataMode:GKSendDataReliable error:nil];
}

#pragma mark -
#pragma mark Session-related methods

- (void)invalidateSession:(GKSession *)session;
{
	if(session != nil) {
		[session disconnectFromAllPeers]; 
		session.available = NO; 
		[session setDataReceiveHandler: nil withContext: NULL]; 
		session.delegate = nil; 
	}
}

- (void)receiveData:(NSData *)data fromPeer:(NSString *)peer inSession:(GKSession *)session context:(void *)context 
{ 
	unsigned char *incomingPacket = (unsigned char *)[data bytes];
	
	if (incomingPacket[0] == 1)
	{
		colorButton.buttonColor = [UIColor redColor];
	}
	else
	{
		colorButton.buttonColor = [UIColor greenColor];
	}
}

#pragma mark -
#pragma mark GKPeerPickerControllerDelegate methods

- (void)peerPickerControllerDidCancel:(GKPeerPickerController *)picker 
{ 
	picker.delegate = nil;
    [picker autorelease]; 
	
	if(self.connectionSession != nil)	
	{
		[self invalidateSession:self.connectionSession];
		self.connectionSession = nil;
	}	
} 

- (GKSession *)peerPickerController:(GKPeerPickerController *)picker sessionForConnectionType:(GKPeerPickerConnectionType)type 
{ 
	GKSession *session = [[GKSession alloc] initWithSessionID:@"edu.matcmadison.gamekitexample" displayName:nil sessionMode:GKSessionModePeer]; 
	return [session autorelease];
}

- (void)peerPickerController:(GKPeerPickerController *)picker didConnectPeer:(NSString *)peerID toSession:(GKSession *)session 
{ 
	self.connectionPeerId = peerID;
	
	self.connectionSession = session;
	self.connectionSession.delegate = self; 
	[self.connectionSession setDataReceiveHandler:self withContext:NULL];
	
	// Done with the Peer Picker so dismiss it.
	[picker dismiss];
	picker.delegate = nil;
	[picker autorelease];	
} 

#pragma mark -
#pragma mark Accessors

@synthesize connectionSession;
@synthesize connectionPeerId;

@end
